#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>
#include <ext/pb_ds/tree_policy.hpp>

using namespace std;
using namespace __gnu_pbds;

#define int int64_t

#ifndef LOCAL
#define endl "\n"
#define DBG(x)
#else
#define DBG(x) cout << #x << " = " << x << endl;
#endif

template<typename t>
istream &operator>>(istream &in, vector<t> &x) {
    for (auto &y : x) {
        in >> y;
    }
    return in;
};

ostream &operator<<(ostream &out, const vector<int> &a) {
    for (auto x : a) {
        out << x << " ";
    }
    return out;
}

template<typename t>
ostream &operator<<(ostream &out, const vector<t> &a) {
    for (auto &x : a) {
        out << x << endl;
    }
    return out;
}

template<typename t1, typename t2>
istream &operator>>(istream &in, pair<t1, t2> &a) {
    in >> a.first >> a.second;
    return in;
};

template<typename t1, typename t2>
ostream &operator<<(ostream &out, const pair<t1, t2> &a) {
    out << a.first << " " << a.second;
    return out;
};

mt19937 rnd;

template<typename t>
struct Node {
    t x;
    int y;
    int sz;
    Node<t> *left;
    Node<t> *right;
    Node<t> *prev;

    Node(const t &x1) : x(x1), y(rnd()), sz(1), left(nullptr), right(nullptr), prev(nullptr) {}
};

template<typename t>
int size(Node<t> *tree) {
    return tree == nullptr ? 0 : tree->sz;
}

template<typename t>
void recalc(Node<t> *tree) {
    tree->sz = 1 + size(tree->left) + size(tree->right);
    if (tree->left) {
        tree->left->prev = tree;
    }
    if (tree->right) {
        tree->right->prev = tree;
    }
    tree->prev = nullptr;
}

template<typename t>
Node<t> *merge(Node<t> *t1, Node<t> *t2) {
    if (t1 == nullptr) {
        return t2;
    }
    if (t2 == nullptr) {
        return t1;
    }
    if (t1->y < t2->y) {
        t1->right = merge(t1->right, t2);
        recalc(t1);
        return t1;
    } else {
        t2->left = merge(t1, t2->left);
        recalc(t2);
        return t2;
    }
}

template<typename t>
void split(Node<t> *tree, const t &x, Node<t> *&t1, Node<t> *&t2) {
    if (tree == nullptr) {
        t1 = nullptr;
        t2 = nullptr;
    } else {
        if (tree->x <= x) {
            split(tree->right, x, tree->right, t2);
            t1 = tree;
            recalc(t1);
        } else {
            split(tree->left, x, t1, tree->left);
            t2 = tree;
            recalc(t2);
        }
    }
}

template<typename t>
Node<t> *insert(Node<t> *tree, Node<t> *nn) {
    if (tree == nullptr) {
        return nn;
    }
    if (nn->y < tree->y) {
        if (nn->x > tree->x) {
            nn->left = tree;
        } else {
            nn->right = tree;
        }
        recalc(nn);
        return nn;
    } else {
        if (nn->x > tree->x) {
            tree->right = insert(tree->right, nn);
            recalc(tree);
            return tree;
        } else {
            tree->left = insert(tree->left, nn);
            recalc(tree);
            return tree;
        }
    }
}

template<typename t>
Node<t> *insert(Node<t> *tree, const t &nn) {
    return insert(tree, new Node<t>(nn));
}

template<typename t>
Node<t> *erase(Node<t> *tree, const t &nn) {
    if (tree == nullptr) {
        return tree;
    }
    if (tree->x == nn) {
        return merge(tree->left, tree->right);
    }
    if (nn > tree->x) {
        tree->right = erase(tree->right, nn);
    } else {
        tree->left = erase(tree->left, nn);
    }
    recalc(tree);
    return tree;
}

template<typename t>
Node<t> *find_kth(Node<t> *root, int k) {
    if (root == nullptr) {
        return root;
    }
    if (size(root->left) == k) {
        return root;
    } else if (size(root->left) < k) {
        return find_kth(root->right, k - 1 - size(root->left));
    } else {
        return find_kth(root->left, k);
    }
}

template<typename t>
int get_ind(Node<t> *tree, const t &x) {
    if (tree == nullptr) {
        return 0;
    }
    if (x == tree->x) {
        return size(tree->left);
    } else if (x < tree->x) {
        return get_ind(tree->left, x);
    } else {
        return get_ind(tree->right, x) + 1 + size(tree->left);
    }
}

pair<int, int> findchi(Node<pair<int, int> > *ch, Node<double> *x, int i) {
    int ind = get_ind(x, double(i));
    return find_kth(ch, ind)->x;
};

template<typename t>
Node<t> *find_last(Node<t> *r) {
    if (r == nullptr) {
        return r;
    }
    while (r->right != nullptr) {
        r = r->right;
    }
    return r;
}

template<typename t>
Node<t> *find_first(Node<t> *r) {
    if (r == nullptr) {
        return r;
    }
    while (r->left != nullptr) {
        r = r->left;
    }
    return r;
}

template<typename t>
bool is_right(Node<t> *tr) {
    return tr != nullptr && tr->prev != nullptr && tr->prev->right == tr;
}

double findx1(pair<int, int> a, pair<int, int> b) {
    return (a.second - b.second) * 1.0 / (b.first - a.first);
}

void add(Node<pair<int, int> > *&ch, Node<double> *&x, pair<int, int> newline) {
    auto xch = find_last(ch);
    if (xch == nullptr) {
        assert(false);
    }
    if (xch->x < newline) {
        double x1 = findx1(xch->x, newline);
        auto xl = find_last(x);
        while (xl != nullptr && xl->x > x1) {
            x = erase(x, xl->x);
            xl = find_last(xl);
            ch = erase(ch, xch->x);
            xch = find_last(ch);
        }
        x = insert(x, x1);
        ch = insert(ch, newline);
    } else {
        int ind = get_ind(ch, newline);
        assert(ind != 0);
        auto ptr = find_kth(ch, ind - 1)->x;
        double x11 = find_kth(x, ind - 1)->x;
        double x1 = findx1(ptr, newline);
        if (x11 < x1) {
            return;
        }
        while (ind > 0) {
            ptr = find_kth(ch, ind - 1)->x;
            x11 = find_kth(x, ind - 1)->x;
            x1 = findx1(ptr, newline);
            if (x11 < x1) {
                return;
            }
            x = erase(x, x11);
            ch = erase(ch, ptr);
            --ind;
        }
        ch = insert(ch, newline);
        x = insert(x, x1);
    }
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
#ifdef LOCAL
    freopen("/home/roi/CLionProjects/A/input.txt", "rt", stdin);
#endif
    int n;
    cin >> n;
    vector<pair<int, int> > a(n);
    cin >> a;
    sort(a.begin(), a.end());
    int res = 0;

    Node<pair<int, int> > *ch = nullptr;
    Node<double> *x = nullptr;
    ch = insert(ch, pair<int, int>(0, 0));

    for (int i = 0; i < n; ++i) {
        auto chi = findchi(ch, x, i);
        int cres2 = chi.second + chi.first * i;
        int cres = (n - i) * a[i].first + cres2;
        res = max(cres, res);
        if (a[i].second != 0) {
            pair<int, int> newline = {a[i].second, -a[i].second * i};
            add(ch, x, newline);
        }
    }
    cout << res << endl;
    return 0;
}