#include <iostream>
#include <vector>
#include <algorithm>


using namespace std;


#define left(v) 2 * v + 1
#define right(v) 2 * v + 2
#define parent(v) (v - 1) / 2

class LST {
    vector<int> data, index;
    int head_size;

    void update(int v) {
        if (data[left(v)] > data[right(v)]) {
            data[v] = data[left(v)];
            index[v] = index[left(v)];
        } else {
            data[v] = data[right(v)];
            index[v] = index[right(v)];
        }
    }

public:
    LST() {};

    template<typename It>
    LST(It begin, It end) {
        int n = end - begin;

        int m = 1;
        for (; m < n; m <<= 1);

        head_size = m - 1;

        data.resize(head_size + m);
        index.resize(head_size + m);

        for (int i = 0; i < n; ++i) {
            data[head_size + i] = *(begin++);
            index[head_size + i] = i;
        }

        for (int i = head_size - 1; i >= 0; --i) {
            update(i);
        }
    }

    void set(int i, int v) {
        i += head_size;
        data[i] = v;

        while (i) {
            i = parent(i);
            update(i);
        }
    }

    int get() const {
        return index[0];
    }

    bool is_max(int v) const {
        return v == data[0];
    }
};

#undef left
#undef right
#undef parent


int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);

    int n, m, q;
    cin >> n >> m >> q;

    vector<vector<int>> field(n, vector<int>(m));
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            cin >> field[i][j];
        }
    }

    vector<LST> nLST(n), mLST(m);
    for (int i = 0; i < n; ++i) {
        nLST[i] = LST(field[i].begin(), field[i].end());
    }

    for (int i = 0; i < m; ++i) {
        vector<int> col(n);
        for (int j = 0; j < n; ++j) {
            col[j] = field[j][i];
        }

        mLST[i] = LST(col.begin(), col.end());
    }

    vector<int> nmaxes(n, -1), mmaxes(m, -1);

    int cnt = 0;
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            if (nLST[i].is_max(field[i][j]) && mLST[j].is_max(field[i][j])) {
                ++cnt;
                nmaxes[i] = j;
                mmaxes[j] = i;
            }
        }
    }

    int x, y, v;
    for (int i = 0; i < q; ++i) {
        cin >> x >> y >> v;
        --x;
        --y;

        if (nmaxes[x] == y) {
            --cnt;
        } else {
            if (nmaxes[x] != -1) {
                --cnt;
            }

            if (mmaxes[y] != -1) {

                --cnt;
            }
        }

        nLST[x].set(y, v);
        mLST[y].set(x, v);

        field[x][y] = v;

        if (nLST[x].is_max(v) && mLST[y].is_max(v)) {
            nmaxes[x] = y;
            mmaxes[y] = x;
            ++cnt;

            cout << cnt << '\n';

            continue;
        }

        int nind = nLST[x].get();
        if (mLST[nind].is_max(field[x][nind])) {
            nmaxes[x] = nind;
            mmaxes[nind] = x;

            ++cnt;
        }

        int mind = mLST[y].get();
        if (nLST[mind].is_max(field[mind][y])) {
            nmaxes[y] = mind;
            mmaxes[mind] = y;

            ++cnt;
        }

        cout << cnt << '\n';
    }
    
    return 0;
}