import java.io.*;
import java.math.*;
import java.util.*;

public class D1 {

	BufferedReader in;
	PrintWriter out;
	StringTokenizer st;

	public void run() {
		in = new BufferedReader(new InputStreamReader(System.in));
		out = new PrintWriter(System.out);
		solve();
		out.close();
	}

	public String nextToken() {
		while (st == null || !st.hasMoreTokens()) {
			try {
				st = new StringTokenizer(in.readLine());
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return st.nextToken();
	}

	public int nextInt() {
		return Integer.parseInt(nextToken());
	}

	public long nextLong() {
		return Long.parseLong(nextToken());
	}

	public class Point implements Comparable<Point> {
		int x;
		int y;
		int n;

		public Point(int x, int y, int n) {
			this.x = x;
			this.y = y;
			this.n = n;
		}

		public int dist(Point p) {
			return Math.max(Math.abs(x - p.x), Math.abs(y - p.y));
		}

		@Override
		public int compareTo(Point o) {
			return n - o.n;
		}
	}
	
	public class Pointx implements Comparable<Pointx> {
		int x;
		int y;
		int n;

		public Pointx(int x, int y, int n) {
			this.x = x;
			this.y = y;
			this.n = n;
		}

		public Pointx(Point p) {
			this(p.x, p.y, p.n);
		}
		
		public int dist(Pointx p) {
			return Math.max(Math.abs(x - p.x), Math.abs(y - p.y));
		}

		@Override
		public int compareTo(Pointx o) {
			return x - o.x;
		}
	}
	
	public class Edge implements Comparable<Edge> {
		int from;
		int to;
		BigInteger len;

		public Edge(int from, int to, BigInteger len) {
			this.from = from;
			this.to = to;
			this.len = len;
		}

		@Override
		public int compareTo(Edge o) {
			int x = len.compareTo(o.len);
			if (x != 0) {
				return x;
			}
			return to - o.to;
		}
	}

	BigInteger[] pow;
	ArrayList<Edge>[] edge;

	public void solve() {
		int n = nextInt();
		int m = nextInt();
		int k = nextInt();
		pow = new BigInteger[Math.max(m, n) + 1];
		for (int i = 0; i < pow.length; i++) {
			pow[i] = BigInteger.ONE.shiftLeft(i);
		}
		Pointx[] px = new Pointx[k];
//		Pointy[] py = new Pointy[k];
		for (int i = 0; i < px.length; i++) {
			px[i] = new Pointx(nextInt(), nextInt(), i);
//			py[i] = new Pointy(p[i]);
		}
		Arrays.sort(px);
//		Arrays.sort(py);
		edge = new ArrayList[k];
		for (int i = 0; i < edge.length; i++) {
			edge[i] = new ArrayList<>();
		}
//		for (int i = 0; i < px.length; i++) {
//			System.out.println(px[i].n);
//		}
		for (int i = 0; i < px.length; i++) {
			int maxless = -1;
			int minup = Integer.MAX_VALUE;
			for (int j = i + 1; j < px.length; j++) {
				if (px[j].y < px[i].y && px[j].y > maxless) {
					maxless = px[j].y;
					edge[px[i].n].add(new Edge(px[i].n, px[j].n, pow[px[i].dist(px[j])]));
				}
				if (px[j].y > px[i].y && px[j].y < minup) {
					minup = px[j].y;
					edge[px[i].n].add(new Edge(px[i].n ,px[j].n, pow[px[i].dist(px[j])]));
				}
			}
			maxless = -1;
			minup = Integer.MAX_VALUE;
			for (int j = i - 1; j >= 0; j--) {
				if (px[j].y < px[i].y && px[j].y > maxless) {
					maxless = px[j].y;
					edge[px[i].n].add(new Edge(px[i].n, px[j].n, pow[px[i].dist(px[j])]));
				}
				if (px[j].y > px[i].y && px[j].y < minup) {
					minup = px[j].y;
					edge[px[i].n].add(new Edge(px[i].n ,px[j].n, pow[px[i].dist(px[j])]));
				}
			}
		}
//		for (int i = 0; i < edge.length; i++) {
//			for (Edge e : edge[i]) {
//				System.out.println(e.from + " " + e.to + " " + e.len);
//			}
//		}
//		System.out.println();
		TreeSet<Edge> set = new TreeSet<>();
		boolean[] used = new boolean[k];
		set.add(new Edge(-1, 0, BigInteger.ZERO));
		int[] prev = new int[k];
		for (int i = 0; i < prev.length; i++) {
			prev[i] = -1;
		}
		while (true) {
//			for (Edge e : set) {
//				System.out.println(e.from + " " + e.to);
//			}
			while (used[set.first().to]) {
				set.pollFirst();
			}
			Edge e = set.pollFirst();
			int number = e.to;
			prev[number] = e.from;
			used[number] = true;
			BigInteger len = e.len;
//			System.out.println(number + " " + len);
			if (number == k - 1) {
				break;
			}
//			System.out.println(number + " " + e.len);
			for (Edge edge : edge[number]) {
				if (!used[edge.to]) {
//					System.out.println(edge.from + " " + edge.to + " " + len.add(e.len));
					set.add(new Edge(number, edge.to, len.add(edge.len)));
				}
			}
//			int number = -1;
//			BigInteger min = pow[pow.length - 1];
//			for (int i = 0; i < len.length; i++) {
//				if (!used[i] && len[i].compareTo(min) < 0) {
//					min = len[i];
//					number = i;
//				}
//			}
//			used[number] = true;
//			if (number == k - 1) {
//				break;
//			}
//			for (int i = 0; i < prev.length; i++) {
//				BigInteger bg = min.add(pow[edge[number][i]]);
//				if (len[i].compareTo(bg) > 0) {
//					len[i] = bg;
//					prev[i] = number;
//				}
//			}
		}
		Stack<Integer> stack = new Stack<>();
		int th = k - 1;
		stack.add(th);
		while (prev[th] != -1) {
			th = prev[th];
			stack.add(th);
		}
		out.println(stack.size());
		while (!stack.isEmpty()) {
			out.print(stack.pop() + 1 + " ");
		}
	}

	// 4 5 3
	// 1 1
	// 2 3
	// 4 5

	// 5 6 9
	// 1 1
	// 4 3
	// 4 6
	// 2 5
	// 3 1
	// 3 3
	// 3 6
	// 5 4
	// 5 6

	public static void main(String[] args) {
		new D1().run();
	}

}
