#include <iostream>
#include <cmath>
#include <vector>
#include <algorithm>
#include <map>

using namespace std;

const long long inf = 1e15;




struct node {
	long long l, r;
	node * cl;
	node * cr;
	long long add = 0;
	long long max;

	node() {
		l = r = add = max = 0;
		cl = cr = nullptr;
	}
};

node * build(long long l, long long r, vector < long long > &a) {
	if (l > r) return nullptr;
	node * root = new node();
	root->l = l;
	root->r = r;
	root->add = 0;
	if (l == r) {
		root->max = a[l];
		return root;
	}

	long long mid = (l + r) / 2;

	root->cl = build(l, mid, a);
	root->cr = build(mid + 1, r, a);

	root->max = max(root->cl->max, root->cr->max);
	return root;
}

void update(node * root, long long l, long long r, long long delta) {
	if (root->l > r || root->r < l) {
		return;
	}

	if (root->l >= l && root->r <= r) {
		root->add += delta;
		return;
	}

	update(root->cl, l, r, delta);
	update(root->cr, l, r, delta);

	root->max = max(root->cl->max + root->cl->add, root->cr->max + root->cr->add);
	return;
}

long long query(node * root, long long l, long long r) {
	if (root->l > r || root->r < l) {
		return -inf;
	}

	if (root->l >= l && root->r <= r) {
		return root->add + root->max;
	}

	long long ans1 = query(root->cl, l, r);
	long long ans2 = query(root->cr, l, r);

	return max(ans1, ans2) + root->add;
}


int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
	long long n;
	cin >> n;

	vector < long long > a(n);
	map < int, long long > pos;
	for (long long i = 0; i < n; i++) {
		cin >> a[i];
		pos[a[i]] = i;
	}

	node * root = build(0, n - 1, a);

	long long ans = 0;

	vector < pair < int, long long > > p;
	vector < bool > ok(n, false);

	for (long long i = 0; i < n; i++) {
		p.push_back({ a[i], i });
	}

	sort(p.begin(), p.end());

	for (long long i = 0; i < n; i++) {
		long long l = p[i].second;
		if (ok[l] == true) {
			continue;
		}
		ans++;
		long long q = query(root, l, n - 1);
		long long r = pos[q];
		update(root, l, r, -inf);
		for (long long j = l; j <= r; j++) {
			ok[j] = true;
		}
	}

	cout << ans;



	system("pause");
	return 0;
}