#include <iostream>
#include <cmath>
#include <vector>
#include <algorithm>
#include <map>

using namespace std;

const long long inf = 1e15;




struct node {
	long long l, r;
	node * cl;
	node * cr;
	long long max;
	long long pos;

	node() {
		l = r = max = 0;
		cl = cr = nullptr;
	}
};

node * build(long long l, long long r, vector < long long > &a) {
	if (l > r) return nullptr;
	node * root = new node();
	root->l = l;
	root->r = r;

	if (l == r) {
		root->max = a[l];
		root->pos = l;
		return root;
	}

	long long mid = (l + r) / 2;

	root->cl = build(l, mid, a);
	root->cr = build(mid + 1, r, a);

	if (root->cl->max > root->cr->max) {
		root->max = root->cl->max;
		root->pos = root->cl->pos;
	}
	else {
		root->max = root->cr->max;
		root->pos = root->cr->pos;
	}
	return root;
}

void update(node * root, long long id, long long val) {
	if (root->l > id || root->r < id) {
		return;
	}

	if (root->l == root->r) {
		root->max = val;
		return;
	}

	update(root->cl, id, val);
	update(root->cr, id, val);

	if (root->cl->max > root->cr->max) {
		root->max = root->cl->max;
		root->pos = root->cl->pos;
	}
	else {
		root->max = root->cr->max;
		root->pos = root->cr->pos;
	}
	return;
}

pair < long long, long long > query(node * root, long long l, long long r) {
	if (root->l > r || root->r < l) {
		return { -inf, -1 };
	}

	if (root->l >= l && root->r <= r) {
		return { root->max, root->pos };
	}

	auto ans1 = query(root->cl, l, r);
	auto ans2 = query(root->cr, l, r);

	if (ans1.first > ans2.first) {
		return ans1;
	}
	return ans2;
}

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
	long long n;
	cin >> n;

	vector < long long > a(n);
	map < long long, long long > pos;
	for (long long i = 0; i < n; i++) {
		cin >> a[i];
		pos[a[i]] = i;
	}

	node * root = build(0, n - 1, a);

	long long ans = 0;

	vector < pair < long long, long long > > p;
	vector < int > ok(n, 0);

	for (long long i = 0; i < n; i++) {
		p.push_back({ a[i], i });
	}

	sort(p.begin(), p.end());

	for (long long i = 0; i < n; i++) {
		long long l = p[i].second;
		if (ok[l] == 0) {
			ans++;
			auto q = query(root, l, n - 1);
			long long r = q.second;
			for (long long j = l; j <= r; j++) {
				ok[j] = i + 1;
				update(root, j, -inf);
			}
		}
	}

	cout << ans;
	/*cout << endl;

	for (int i = 0; i < n; i++) {
	cout << ok[i] << " ";
	}*/



	system("pause");
	return 0;
}