#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <stdio.h>
#include <map>


using namespace std;

typedef long long ll;
typedef long double dbl;

template<class T>
void print(vector<T> s){
    for (int i = 0; i < s.size(); i++)
        cout << s[i] << " ";
    cout << endl;
}

struct Point{
    int x, y;
    int cnt;
    Point* left;
    Point* right;
};

Point* createPoint(int x){
    Point* p = new Point();
    p -> x = x;
    p -> y = rand();
    p -> cnt = 1;
    p -> left = nullptr;
    p -> right = nullptr;
    return p;
}

Point* update(Point* v){
    if (v == NULL)
        return v;
    v -> cnt = 1;
    if (v -> left != NULL)
        v -> cnt += v -> left -> cnt;
    if (v -> right != NULL)
        v -> cnt += v -> right -> cnt;
    return v;
}

Point* merge(Point* v, Point* u){
    if (v == NULL)
        return u;
    if (u == NULL)
        return v;
    if (v -> y < u -> y){
        v -> right = merge(v -> right, u);
        v = update(v);
        return v;
    }
    else{
        u -> left = merge(v, u -> left);
        u = update(u);
        return u;
    }
}

pair<Point*, Point*> split(Point* v, int x){
    if (v == NULL)
        return make_pair(v, v);
    pair<Point*, Point*> s;
    if (v -> x >= x){
        s = split(v -> left, x);
        v -> left = s.second;
        v = update(v);
        return make_pair(s.first, v);
    }
    else{
        s = split(v -> right, x);
        v -> right = s.first;
        v = update(v);
        return make_pair(v, s.second);
    }
}

inline Point* add(Point* v, int x){
    Point* u = createPoint(x);
    pair<Point*, Point*> s = split(v, x);
    s.second = merge(u, s.second);
    v = merge(s.first, s.second);
    return v;
}

inline Point* del(Point* v, int x){
    pair<Point*, Point*> s = split(v, x);
    pair<Point*, Point*> lst = split(s.second, x + 1);
    if (lst.first != NULL){
        if (lst.first -> left == NULL)
            lst.first = lst.first -> right;
        else{
            if (lst.first -> right == NULL)
                lst.first = lst.first -> left;
            else
                lst.first = merge(lst.first -> left, lst.first -> right);
        }
    }
    s.second = merge(lst.first, lst.second);
    v = merge(s.first, s.second);
}


void print(Point* v){
    if (v == NULL)
        return;
    print(v -> left);
    cout << v -> x << " ";
    print(v -> right);
}

int main()
{
    #ifdef ONPC
        freopen("test.in", "r", stdin);
    #endif // ONPC
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    int n, p;
    cin >> n >> p;
    vector<int> s(n), lst1(n), lst2(n), lst3(n);
    for (int i = 0; i < n; i++){
        cin >> s[i];
        lst1[i] = s[i] + i;
        lst2[i] = s[i] + n - 1 - i;
        lst3[i] = s[i] + min(n - 1 - i, i);
    }
    sort(lst1.begin(), lst1.end());
    sort(lst2.begin(), lst2.end());
    sort(lst3.begin(), lst3.end());
    vector<int> answer(n, 0);
    for (int i = 0; i < n; i++){
        int x = i;
        int l = 0;
        int r = n;
        while (l + 1 < r){
            int m = (l + r) / 2;
            if (lst1[m] < s[i] + x)
                l = m;
            else
                r = m;
        }
        if (lst1[0] < s[i] + x)
            l++;
        answer[i] = max(answer[i], l + 1);

        x = n - 1 - i;
        l = 0;
        r = n;
        while (l + 1 < r){
            int m = (l + r) / 2;
            if (lst2[m] < s[i] + x)
                l = m;
            else
                r = m;
        }
        if (lst2[0] < s[i] + x)
            l++;
        answer[i] = max(answer[i], l + 1);

        x = min(i, n - 1 - i);
        l = 0;
        r = n;
        while (l + 1 < r){
            int m = (l + r) / 2;
            if (lst3[m] < s[i] + x)
                l = m;
            else
                r = m;
        }
        if (lst3[0] < s[i] + x)
            l++;
        answer[i] = max(answer[i], l + 1);
    }

    vector<int> cnt1(n);
    vector<int> cnt2(n);
    vector<int> cnt3(n);
    Point* root = nullptr;
    root = add(root, s[0]);
    root = add(root, s[n - 1]);
    int m = (n - 1) / 2;
    int cur = n - 2;
    if (n % 2 == 0)
        root = add(root, s[cur--]);
    for (int i = m; i > 0; i--){
        pair<Point*, Point*> ss = split(root, s[i] + i);
        if (ss.first != NULL)
            cnt1[i] = ss.first -> cnt;
        root = merge(ss.first, ss.second);
        root = add(root, s[cur--]);
        root = add(root, s[cur--]);
    }
    root = nullptr;
    root = add(root, s[0]);
    root = add(root, s[1]);
    root = add(root, s[n - 1]);
    cur = 2;
    if (n % 2 == 1)
        root = add(root, s[cur++]);
    for (int i = m + 1; i < n - 1; i++){
        pair<Point*, Point*> ss = split(root, s[i] + n - 1 - i);
        if (ss.first != NULL)
            cnt1[i] = ss.first -> cnt;
        root = merge(ss.first, ss.second);
        root = add(root, s[cur++]);
        root = add(root, s[cur++]);
    }


    root = nullptr;
    for (int i = 1; i <= m; i++){
        pair<Point*, Point*> ss = split(root, s[i] + i);
        if (ss.first != NULL)
            cnt2[i] = ss.first -> cnt;
        ss.second = merge(createPoint(s[i] + i), ss.second);
        root = merge(ss.first, ss.second);
    }
    root = nullptr;
    for (int i = n - 2; i > m; i--){
        pair<Point*, Point*> ss = split(root, s[i] + n - 1 - i);
        if (ss.first != NULL)
            cnt2[i] = ss.first -> cnt;
        ss.second = merge(createPoint(s[i] + n - 1 - i), ss.second);
        root = merge(ss.first, ss.second);
    }


    root = nullptr;
    cur = n - 2;
    if (n % 2 == 0)
        cur--;
    vector<int> kek(n);
    for (int i = m + 1; i <= cur; i++){
        root = add(root, s[i] + cur + 1 - i);
        kek[i] = s[i] + cur + 1 - i;
    }
    int x = 0;
    for (int i = m; i > 0; i--){
        pair<Point*, Point*> ss = split(root, s[i] + i + x);
        if (ss.first != NULL)
            cnt3[i] = ss.first -> cnt;
        root = merge(ss.first, ss.second);
        x += 2;
        root = add(root, s[i] + i - 2 + x);
        kek[i] = s[i] + i - 2 + x;
        root = del(root, kek[cur--]);
        root = del(root, kek[cur--]);
    }
    //print(cnt3);
    root = nullptr;
    cur = 2;
    if (n % 2 == 1)
        cur++;
    for (int i = cur; i < m + 1; i++){
        root = add(root, s[i] + i - cur + 1);
        kek[i] = s[i] + i - cur + 1;
    }
    x = 0;
    for (int i = m + 1; i < n - 1; i++){
        pair<Point*, Point*> ss = split(root, s[i] + n - 1 - i + x);
        if (ss.first != NULL)
            cnt3[i] = ss.first -> cnt;
        root = merge(ss.first, ss.second);
        x += 2;
        root = add(root, s[i] + (n - i - 3 + x));
        kek[i] = s[i] + (n - i - 3 + x);
        root = del(root, kek[cur++]);
        root = del(root, kek[cur++]);
    }

    /*print(cnt1);
    print(cnt2);
    print(cnt3);/**/
    for (int i = 0; i < n; i++)
        cout << max(answer[i], cnt1[i] + cnt2[i] + cnt3[i] + 1) << " ";
    return 0;
}
