#include <iostream>
#include <vector>
#include <algorithm>
#include <map>
#include <cassert>
#include <stack>

using namespace std;

typedef long long ll;

const int N = 3e5 + 7;

struct node {
	int val, ind;
	node(int val = 0, int ind = 0) : val(val), ind(ind) {}
	node operator+(const node &other) const {
		node tmp;
		if (val == other.val) {
			tmp.ind = max(ind, other.ind);
		}
		else if (val > other.val) {
			tmp.ind = ind;
		}
		else {
			tmp.ind = other.ind;
		}
		tmp.val = max(val, other.val);
		return tmp;
	}
};

node t[4 * N];

void build(int l, int r, int v, vector <int> &a) {
	if (l == r) {
		t[v] = node(a[l], l);
	}
	else {
		int m = (l + r) >> 1;
		build(l, m, 2 * v + 1, a);
		build(m + 1, r, 2 * v + 2, a);
		t[v] = t[2 * v + 1] + t[2 * v + 2];
	}
}

node get(int ql, int qr, int l, int r, int v) {
	if (qr < l || r < ql) return node(0, 0);
	if (ql <= l && r <= qr) return t[v];
	int m = (l + r) >> 1;
	return get(ql, qr, l, m, 2 * v + 1) + get(ql, qr, m + 1, r, 2 * v + 2);
}

int solvefast(int n, vector <int> &a) {
	int ans = 0;
	stack <int> s;
	vector <int> p(n);
	build(0, n - 1, 0, a);
	for (int i = n - 1; i >= 0; --i) {
		while (!s.empty() && a[s.top()] >= a[i]) {
			s.pop();
		}
		if (s.empty()) p[i] = n;
		else p[i] = s.top();
		s.push(i);
	}
	for (int l = 0; l < n; ++l) {
		int r = p[l];
		int ind = get(l, r - 1, 0, n - 1 , 0).ind;
		l = ind;
		++ans;
	}
	return ans;
}

int solveslow(int n, vector <int> &a) {
	int ans = 0;
	for (int l = 0; l < n; ++l) {
		int mx = -1;
		int x = n;
		for (int r = l; r < n; ++r) {
			if (a[r] < a[l]) {
				x = r;
				break;
			}
		}
		for (int r = l; r < x; ++r) {
			mx = max(mx, a[r]);
		}
		for (int r = x - 1; r >= l; --r) {
			if (a[r] == mx) {
				++ans;
				l = r;
			}
		}
	}
	return ans; 
}
void stress() {
	while (true) {
		int n = 8;
		vector <int> a(n);
		for (int i = 0; i < n; ++i) {
			a[i] = rand() % 10 + 1;
		}
		if (solveslow(n, a) != solvefast(n, a)) {
			cout << n << "\n";
			for (auto e : a) {
				cout << e << " ";
			}
			cout << "\n";
			cout << solveslow(n, a) << " " << solvefast(n, a) << "\n";
			exit(0);
		}
	}
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	//freopen("input.txt", "r", stdin);
	//freopen("output.txt", "w", stdout);
	int n;
	cin >> n;
	vector <int> a(n);
	for (int i = 0; i < n; ++i) {
		cin >> a[i];
	} 
	//stress();
	cout << solvefast(n, a) << "\n";
}