#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <cmath>
#include <algorithm>
#include <fstream>
#include <queue>
#include <random>
#include <time.h>

using namespace std;

const int MAXN = 4e5 + 7;
const int INF = 2e9 + 7;

mt19937 rnd(rand());

int a[MAXN];

struct Node {
    int x, y, cnt;
    Node *l, *r;
};

Node *init(int x) {
    Node *t = new Node;
    t->x = x;
    t->y = rnd();
    t->cnt = 1;
    t->l = t->r = NULL;
    return t;
}

int cnt(Node *t) {
    if (!t) return 0;
    else return t->cnt;
}

void relax(Node *t) {
    t->cnt = 1 + cnt(t->l) + cnt(t->r);
}

Node *merge(Node *l, Node *r) {
    if (!l) return r;
    if (!r) return l;

    if (l->y < r->y) {
        l->r = merge(l->r, r);
        relax(l);
        return l;
    }
    else {
        r->l = merge(l, r->l);
        relax(r);
        return r;
    }
}

pair <Node*, Node*> split(Node *t, int x) {
    if (!t) return {NULL, NULL};

    if (t->x <= x) {
        auto tmp = split(t->r, x);
        t->r = tmp.first;
        relax(t);
        return {t, tmp.second};
    }
    else {
        auto tmp = split(t->l, x);
        t->l = tmp.second;
        relax(t);
        return {tmp.first, t};
    }
}

Node *insert(Node *t, Node *elem) {
    auto tmp = split(t, elem->x);
    return merge(merge(tmp.first, elem), tmp.second);
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    //freopen("input.txt", "r", stdin);

    int n, p;
    cin >> n >> p;
    for (int i = 0; i < n; ++i) cin >> a[i];

    Node *l = NULL, *r = NULL;
    for (int i = 0; i < n; ++i) {
        r = insert(r, init(a[i] + i));
    }

    for (int i = 0; i < n; ++i) {
        int res = 0;

        auto tmp1 = split(l, a[i] - i - 1);
        res += cnt(tmp1.first);
        l = merge(tmp1.first, tmp1.second);

        auto tmp2 = split(r, a[i] + i - 1);
        res += cnt(tmp2.first);
        r = merge(tmp2.first, tmp2.second);

        cout << res + 1 << '\n';

        auto tmp3 = split(r, a[i] + i - 1);
        auto tmp4 = split(tmp3.second, a[i] + i);
        tmp4.first = merge(tmp4.first->l, tmp4.first->r);
        r = merge(merge(tmp3.first, tmp4.first), tmp4.second);

        l = insert(l, init(a[i] - i));
    }

    return 0;
}

