#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <bitset>
#include <fstream>
#include <algorithm>
#include <iomanip>
#include <ctime>
#define ll long long
#define null NULL
#pragma GCC optimize("O3")

using namespace std;

const ll MOD = 1e9 + 7;

struct solver {

	const int K = 150;
	int n, block_cnt;
	vector<ll> a, b, bup;
	vector<int> ptr;
	vector<vector<pair<ll, int> > > cht;

	solver() {}

	struct line {
		ll k, b;
		int num;
		ll pos;
	};

	vector<pair<ll, int> > build_cht(vector<line> L) {
		vector<line> st;
		int sz = L.size();
		/*cout << "building cht" << endl;
		for (int i = 0; i < sz; ++i) {
			cout << L[i].k << " " << L[i].b << " " << L[i].num << endl;
		}*/
		for (int i = 0; i < sz; ++i) {
			while (!st.empty()) {
				ll PS = st.back().pos;
				if (L[i].k * PS + L[i].b >= st.back().k * PS + st.back().b)
					st.pop_back();
				else
					break;
			}
			if (st.empty())
				st.push_back(L[i]);
			else {
				ll k1 = st.back().k;
				ll b1 = st.back().b;
				ll k2 = L[i].k;
				ll b2 = L[i].b;
				ll d = k2 - k1;
				ll ps = (b1 - b2 + d - 1) / d;
				L[i].pos = ps;
				st.push_back(L[i]);
			}
		}
		vector<pair<ll, int> > res;
		for (int i = 0; i < st.size(); ++i) {
			res.push_back({st[i].pos, st[i].num});
		}
		/*cout << "result" << endl;
		for (auto pp : res) {
			cout << pp.first << " " << pp.second << endl;
		}*/
		return res;
	}

	void update(int block) {
		int L = block * K;
		int R = min((block + 1) * K - 1, n - 1);
		for (int i = L; i <= R; ++i) {
			b[i] += bup[block];
		}
		bup[block] = 0;
		vector<line> to_cht;
		for (int i = L; i <= R; ++i) {
			to_cht.push_back({a[i], a[i] * b[i], i, 0});
		}
		cht[block] = build_cht(to_cht);
		ptr[block] = 0;
	}

	void init(vector<ll> _a) {
		a = _a;
		sort(a.begin(), a.end());
		a.erase(unique(a.begin(), a.end()), a.end());
		n = a.size();
		b.resize(n);
		block_cnt = (n - 1) / K + 1;
		bup.resize(block_cnt);
		ptr.resize(block_cnt);
		cht.resize(block_cnt);
		for (int i = 0; i < block_cnt; ++i) {
			update(i);
		}
		/*cout << "a" << endl;
		for (int i = 0; i < n; ++i) {
			cout << a[i] << " ";
		}
		cout << endl;*/
	}

	void add(int val) {
		//cout << "adding " << val << endl;
		int pos = lower_bound(a.begin(), a.end(), val) - a.begin();
		int block = pos / K;
		for (int i = 0; i < block; ++i) {
			bup[i] += 1;
			if (ptr[i] < cht[i].size() - 1 && bup[i] >= cht[i][ptr[i] + 1].first)
				ptr[i]++;
		}
		for (int i = block * K; i <= pos; ++i) {
			b[i]++;
		}
		update(block);
	}

	ll get(ll val) {
		//cout << "getting " << val << endl;
		ll res = 0;
		int pos = upper_bound(a.begin(), a.end(), val) - a.begin() - 1;
		if (pos < 0)
			return 0;
		int block = pos / K;
		for (int i = 0; i < block; ++i) {
			ll pos = cht[i][ptr[i]].second;
			ll upd = a[pos] * (b[pos] + bup[i]);
			//cout << "update res by " << pos << " in block " << i << endl;
			//cout << "upd = " << upd << endl;
			res = max(res, upd);
		}
		for (int i = block * K; i <= pos; ++i) {
			res = max(res, a[i] * (b[i] + bup[block]));
		}
		//cout << "return " << res << endl;
		return res;
	}

};

struct buyer {
	ll a, b;
	buyer() {}
};

bool a_cmp(buyer a, buyer b) {
	return a.a < b.a;
}

bool b_cmp(buyer a, buyer b) {
	return a.b < b.b;
}

const ll INF = 2e9;
int n;
ll ans;
vector<buyer> a;
vector<ll> bs;
solver S;

signed main() {
	cin >> n;
	a.resize(n);
	for (int i = 0; i < n; ++i) {
		cin >> a[i].a >> a[i].b;
	}
	sort(a.begin(), a.end(), a_cmp);
	for (int i = 0; i < n; ++i) {
		bs.push_back(a[i].b);
	}
	ll plus_price = a[0].a;
	ll plus_cnt = n;
	ans = plus_price * plus_cnt;
	S.init(bs);
	//cout << "ans0 = " << ans << endl;
	for (int i = 0; i < n; ++i) {
		if (i == n - 1)
			plus_price = INF;
		else
			plus_price = a[i + 1].a;
		plus_cnt--;
		ll res = plus_cnt * plus_price;
		//cout << "plus_price = " << plus_price << endl;
		//cout << "res0 = " << res << endl;
		S.add(a[i].b);
		res += S.get(plus_price);
		//cout << "res1 = " << res << endl;
		ans = max(ans, res);
	}
	cout << ans << endl;
}