#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <bitset>
#include <fstream>
#include <algorithm>
#include <iomanip>
#include <ctime>
#define ll long long
#define null NULL
#define int long long

using namespace std;

const ll MOD = 1e9 + 7;

struct solver {

	const int K = 350;
	int n, block_cnt;
	vector<int> a, b, bup, bm;

	solver() {}

	void init(vector<int> _a) {
		a = _a;
		sort(a.begin(), a.end());
		n = a.size();
		b.resize(n);
		block_cnt = (n - 1) / K + 1;
		bup.resize(block_cnt);
		bm.resize(block_cnt);
	}

	void update(int block) {
		int new_max = 0;
		int L = block * K;
		int R = min(block * (K + 1), n - 1);
		for (int i = L; i <= R; ++i) {
			b[i] += bup[block];
			new_max = max(new_max, b[i] * a[i]);
		}
		bm[block] = new_max;
	}

	void add(int val) {
		//cout << "adding " << val << endl;
		int pos = lower_bound(a.begin(), a.end(), val) - a.begin();
		int block = pos / K;
		for (int i = 0; i < block; ++i) {
			bup[i] += 1;
			bm[i] += a[i * K - 1];
		}
		for (int i = block * K; i <= pos; ++i) {
			b[i]++;
		}
		update(block);
	}

	int get(int val) {
		//cout << "getting " << val << endl;
		int res = 0;
		int pos = upper_bound(a.begin(), a.end(), val) - a.begin() - 1;
		if (pos < 0)
			return 0;
		int block = pos / K;
		update(block);
		for (int i = 0; i < block; ++i) {
			res = max(res, bm[i]);
		}
		for (int i = block * K; i <= pos; ++i) {
			res = max(res, a[i] * b[i]);
		}
		//cout << "returning " << res << endl;
		return res;
	}

};

struct buyer {
	int a, b;
	buyer() {}
};

bool a_cmp(buyer a, buyer b) {
	return a.a < b.a;
}

bool b_cmp(buyer a, buyer b) {
	return a.b < b.b;
}

const int INF = 2e9;
int n, ans;
vector<buyer> a;
vector<int> bs;
solver S;

signed main() {
	cin >> n;
	a.resize(n);
	for (int i = 0; i < n; ++i) {
		cin >> a[i].a >> a[i].b;
	}
	sort(a.begin(), a.end(), a_cmp);
	for (int i = 0; i < n; ++i) {
		bs.push_back(a[i].b);
	}
	int plus_price = a[0].a;
	int plus_cnt = n;
	ans = plus_price * plus_cnt;
	S.init(bs);
	//cout << "ans0 = " << ans << endl;
	for (int i = 0; i < n; ++i) {
		if (i == n - 1)
			plus_price = INF;
		else
			plus_price = a[i + 1].a;
		plus_cnt--;
		int res = plus_cnt * plus_price;
		//cout << "plus_price = " << plus_price << endl;
		//cout << "res0 = " << res << endl;
		S.add(a[i].b);
		res += S.get(plus_price);
		//cout << "res1 = " << res << endl;
		ans = max(ans, res);
	}
	cout << ans << endl;
}