#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <cstdio>
#include <algorithm>

using namespace std;

const int INF = 1e9 + 5;

struct node {
	node* l;
	node* r;
	int key, prior, count;

	node() {
		count = 1;
		l = r = nullptr;
		prior = rand();
	}

	node(int key_) {
		count = 1;
		l = r = nullptr;
		key = key_;
		prior = rand();
	}
};

int get_cnt(node* v) {
	if (v == nullptr)
		return 0;
	return v->count;
}

void update(node* v) {
	if (v == nullptr)
		return;
	v->count = get_cnt(v->l) + get_cnt(v->r) + 1;
}

pair<node*, node*> split(node* v, int key) {
	if (v == nullptr)
		return {nullptr, nullptr};

	if (v->key >= key) {
		auto tmp = split(v->l, key);
		v->l = tmp.second;
		update(v);
		return {tmp.first, v};
	}
	
	auto tmp = split(v->r, key);
	v->r = tmp.first;
	update(v);
	return {v, tmp.second};
}

node* merge(node* l, node* r) {
	if (l == nullptr)
		return r;
	if (r == nullptr)
		return l;

	if (r->prior > l->prior) {
		r->l = merge(l, r->l);
		update(r);
		return r;
	}
	
	l->r = merge(l->r, r);
	update(l);
	return l;
}

bool exists(node* v, int key) {
	if (v == nullptr)
		return false;

	if (key == v->key)
		return true;
	if (key < v->key)
		return exists(v->l, key);
	return exists(v->r, key);
}

void insert(node* &root, int key) {
	auto tmp = split(root, key);
	auto tmp1 = split(tmp.second, key + 1);
	if (tmp1.first != nullptr)
		tmp1.first->count++;
	else
		tmp1.first = new node(key);

	root = merge(tmp.first, merge(tmp1.first, tmp1.second));
}

void erase(node* &root, int key) {
	if (!exists(root, key))
		return;
	auto tmp = split(root, key);
	auto tmp1 = split(tmp.second, key + 1);
	if (tmp1.first->count > 1)
		tmp1.first->count--;
	else
		tmp1.first = nullptr;

	root = merge(tmp.first, merge(tmp1.first, tmp1.second));
}

int main() {
	//freopen("input.txt", "r", stdin);
	//freopen("output.txt", "w", stdout);

	ios::sync_with_stdio(false);

	/*node* root = nullptr;
	int q;
	cin >> q;
	for (int i = 0; i < q; i++) {
		int t, key;
		cin >> t >> key;
		if (t == 0) {
			insert(root, key);
		}
		else {
			cout << exists(root, key) << endl;
		}
	}*/

	int n, t;
	cin >> n >> t;

	vector<int> a(n);

	for (int i = 0; i < n; i++)
		cin >> a[i];

	for (int i = 0; i < n; i++) {
		vector<int> now;
		for (int j = 0; j < n; j++) {
			now.push_back(a[j] + abs(i - j));
		}
		sort(now.begin(), now.end());
		int p = lower_bound(now.begin(), now.end(), a[i]) - now.begin();
		cout << p + 1 << endl;
	}

	return 0;
}