#include <algorithm>
#include <iostream>
using namespace std;

#ifndef AC
    #define MAX_N 262144
    #define MAX_TREE 524288
#else
    #define MAX_N 16
    #define MAX_TREE 32
#endif

struct Customer {
    long long a, b, i;
};

bool inUse[MAX_N];

bool cmpByA(const Customer& a, const Customer& b) {
    if (a.a > b.a)               return true;
    if (a.a == b.a && a.i < b.i) return true;
    return false;
}

bool cmpByB(const Customer& a, const Customer& b) {
    if (a.b < b.b)               return true;
    if (a.b == b.b && a.i < b.i) return true;
    return false;
}

struct Node {
    long long maxV, maxC;
    long long ifrom;
    long long decrease = 0;
} tree[MAX_TREE];

long long getTrueValueFrom(long long tree_index) {
    //cout << "CHECK FOR IN USE " << tree_index << " " << tree[tree_index].ifrom << " " << inUse[tree[tree_index].ifrom] << endl;
    if(inUse[tree[tree_index].ifrom])   return 0;
    return tree[tree_index].maxV - tree[tree_index].decrease * tree[tree_index].maxC;
}

void setMaxTo(long long to, long long from) {
    tree[to].maxV = getTrueValueFrom(from);
    tree[to].maxC = tree[from].maxC;
    tree[to].ifrom = tree[from].ifrom;
}

void build(long long v = 1) {
    if (v >= MAX_N)  return;
    build(v * 2);
    build(v * 2 + 1);
    if (getTrueValueFrom(v * 2 + 1) > getTrueValueFrom(v * 2))
        setMaxTo(v, v * 2 + 1);
    else
        setMaxTo(v, v * 2);
}

void decreaseToRoot(long long tree_index) {
    ++tree[tree_index].decrease;
    long long prev = tree_index;
    while (tree_index != 1) {
        tree_index /= 2;
        if (getTrueValueFrom(prev ^ 1) > getTrueValueFrom(prev))
            setMaxTo(tree_index, prev ^ 1);
        else
            setMaxTo(tree_index, prev);
        prev = tree_index;
    }
}

void decreasePrefix(long long right) {
    long long left = MAX_N;
    right += MAX_N;
    while (right >= left) {
        if (left & 1)           decreaseToRoot(left);
        if (!(right & 1))       decreaseToRoot(right);
        left = (left + 1) / 2;
        right = (right - 1) / 2;
    }
}

long long getMaximum() {
    return getTrueValueFrom(1);
}

Customer custA[MAX_N], custB[MAX_N];
long long byIndex[MAX_N];

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
#ifdef AC
    freopen("input.txt", "r", stdin);
#endif // AC
    long long n, a, b;
    cin >> n;
    for (long long i = 0; i < n; ++i) {
        cin >> a >> b;
        custA[i] = {a, b, i};
        custB[i] = {a, b, i};
    }
    sort(custA, custA + n, &cmpByA);
    sort(custB, custB + n, &cmpByB);

    int prevChange = 0;
    for (long long i = 0, j = MAX_N; i < n; ++i, ++j) {
        byIndex[custB[i].i] = i;
        tree[j].maxC = custB[i].b;
        tree[j].ifrom = i;
        if(i != 0 && custB[i].b != custB[i - 1].b)
            prevChange = i;
        tree[j].maxV = custB[i].b * (n - prevChange);
    }
    build();

    long long bestAns = getMaximum();
    for (long long i = 0; i < n; ++i) {
        inUse[byIndex[custA[i].i]] = 1;
        decreasePrefix(byIndex[custA[i].i]);
        //cout << bestAns << "\n";
        long long newAns = custA[i].a * (i + 1) + getMaximum();
        //cout << getMaximum() << " ";
        /*cout << custA[i].a << " " << tree[1].maxC << endl;
        for(int i = 1; i < MAX_TREE; ++i)
            cout << "{" << tree[i].maxV << " " << tree[i].maxC << " " << tree[i].decrease << "} ";
        cout << endl;
        */if (newAns > bestAns)
            bestAns = newAns;
    }
    cout << bestAns << "\n";
    return 0;
}
