#include <iostream>
#include <algorithm>
#include <cstdio>
#include <vector>
#include <cassert>
#include <set>

using namespace std;

const int MAXN = 5e5;

int n;
int a[MAXN], res[MAXN];

vector <int> all;
int add;

struct Treap {
    int key, prior;
    Treap *left, *right;
    int sz, w;
    Treap(int key = 0): key(key), prior(rand()), left(NULL), right(NULL), sz(1), w(1) {}
};

void update(Treap *v) {
    if (!v)
        return;
    int lsz = (v->left) ? v->left->sz : 0;
    int rsz = (v->right) ? v->right->sz : 0;
    v->sz = lsz + rsz + v->w;
}

Treap *merge(Treap *l, Treap *r) {
    if (l == NULL)
        return r;
    if (r == NULL)
        return l;
    if (l->prior > r->prior) {
        l->right = merge(l->right, r);
        update(l);
        return l;
    } else {
        r->left = merge(l, r->left);
        update(r);
        return r;
    }
}

void split(Treap *root, Treap *&l, Treap *&r, int key) {
    if (root == NULL) {
        l = r = NULL;
        return;
    }
    if (root->key < key) {
        Treap *tmp_l, *tmp_r;
        split(root->right, tmp_l, tmp_r, key);
        root->right = tmp_l;
        l = root, r = tmp_r;
    } else {
        Treap *tmp_l, *tmp_r;
        split(root->left, tmp_l, tmp_r, key);
        root->left = tmp_r;
        l = tmp_l, r = root;
    }
    update(root);
}

Treap *root = NULL;

void init() {
    root = NULL;
}

void insert(int v) {
    Treap *l, *m, *r;
    split(root, l, r, v);
    split(r, m, r, v + 1);
    if (!m)
        m = new Treap(v);
    else
        m->w++;
    root = merge(merge(l, m), r);
}

int get_lt(int v) {
    Treap *l, *r;
    split(root, l, r, v);
    int res = (l ? (l->sz) : 0);
    root = merge(l, r);
    return res;
}

int main() {
    //freopen("input.txt", "r", stdin);
    ios_base::sync_with_stdio(false);

    int p; cin >> n >> p;
    for (int i = 0; i < n; i++)
        cin >> a[i];

    fill(res, res + MAXN, 0);

    init(); add = 0;
    for (int i = 0; i < n; i++) {
        res[i] += get_lt(a[i] - add);
        insert(a[i] - add);
        add++;
    }
    init(); add = 0;
    for (int i = n - 1; i >= 0; i--) {
        res[i] += get_lt(a[i] - add);
        insert(a[i] - add);
        add++;
    }

    for (int i = 0; i < n; i++)
        cout << res[i] + 1 << endl;

    return 0;
}
