#include <iostream>
#include <vector>
#include <cassert>
#include <set>
#include <algorithm>
#include <cstdio>
#define FOR(i, n) for (int i = 0; i < n; ++i)
typedef long long ll;
struct fenwick {
	std::vector<int> f;

	fenwick(int n) {
		f.resize(n + 10);
	}

	void add(int x, int val) {
		for (int i = x; i < f.size(); i = (i | (i + 1))) {
			f[i] += val;
		}
	}
	int get(int r) {
		int sum = 0;
		for (int i = r; i >= 0; i = (i & (i + 1)) - 1) {
			sum += f[i];
		}
		return sum;
	}
	int get(int l, int r) {
		return get(r) - get(l - 1);
	}
};

int getInd(int x, std::vector<int>&a) {
	auto it = std::lower_bound(a.begin(), a.end(), x);
	return it - a.begin();
}
int distTo(int i, int a, int b) {
	return std::min(abs(i - a), abs(i - b));
}

int main() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(0);
	int n, p;
	std::cin >> n >> p;
	std::vector<int>a(n);
	FOR(i, n) {
		std::cin >> a[i];
	}
	if (p == 1) {
		std::vector<int> answ(n);
		std::vector<int> compress1, compress2;
		fenwick first(n), second(n);
		FOR(i, n) {
			compress1.push_back(a[i] - i);
			compress2.push_back(a[i] + i);
		}
		std::sort(compress1.begin(), compress1.end());
		std::sort(compress2.begin(), compress2.end());
		FOR(i, n) {
			second.add(getInd(a[i] + i, compress2), 1);
		}
		FOR(j, n) {
			int f1 = second.get(getInd(a[j] + j, compress2) - 1);
			int f2 = first.get(getInd(a[j] - j, compress1) - 1);
			second.add(getInd(a[j] + j, compress2), -1);
			first.add(getInd(a[j] - j, compress1), 1);
			std::cout << f1 + f2 + 1 << '\n';
		}
	}
	else {
		std::vector<int> answ(n);
		FOR(i, n) {
			FOR(dist, n) {
				int first = i - dist;
				int second = i + dist;
				if (first < 0) {
					first = -1e9;
				}
				if (second >= n) {
					second = 1e9;
				}
				if (first == -1e9 && second == 1e9) {
					break;
				}
				int k = 0;
				FOR(j, n) {
					int distFirst = 0;
					if (j > first && j < second) {
						distFirst = distTo(j, first, second);
					}
					if (distFirst + a[j] < distTo(i, first, second) + a[i]) {
						k++;
					}
				}
				if (i == 3) {
					//std::cout << "DIST " << first << ' ' << second <<  ' ' << k << ' ' << distTo(i, first, second) << '\n';
				}
				answ[i] = std::max(answ[i], k + 1);
			}
		}
		FOR(i, n) {
			std::cout << answ[i] << '\n';
		}
	}
	return 0;
}