#include <iostream>
#include <algorithm>
#include <vector>
#include <set>

using namespace std;

long long base = 1000000000000000000;

struct bn {
	vector <long long> q;

	bn() { q.clear(); }

	bn operator +(const bn& b) const {
		bn ret;

		long long rem = 0;
		for (int i = 0; i < max(q.size(), b.q.size()); i++) {
			if (i < q.size() && b.q.size()) {
				ret.q.push_back((q[i] + b.q[i] + rem) % base);
				rem = (q[i] + b.q[i] + rem) / base;
			}
			else if (i < q.size()) {
				ret.q.push_back((q[i] + rem) % base);
				rem = (q[i] + rem) / base;
			}
			else if (i < b.q.size()) {
				ret.q.push_back((b.q[i] + rem) % base);
				rem = (b.q[i] + rem) / base;
			}
		}

		if (rem) ret.q.push_back(rem);

		return ret;
	}

	bool operator ==(const bn& b) const {
		bool tr = b.q.size() == q.size();
		for (int i = 0; i < q.size() && tr; i++)
			if (q[i] != b.q[i]) tr = false;

		return tr;
	}
};

bool operator <(const bn& a, const bn& b) {
	if (a == b) return false;

	if (a.q.size() != b.q.size()) return a.q.size() < b.q.size();

	for (int i = a.q.size() - 1; i >= 0; i--) if (a.q[i] != b.q[i]) return a.q[i] < b.q[i];
}

bool operator >(const bn& a, const bn& b) {
	return b < a;
}

bn dbl(bn x) {
	return x + x;
}

vector <vector <pair <int, bn>>> g;

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);

	int n, m, k;
	cin >> n >> m >> k;

	g.resize(k);
	vector <pair <int, int>> q(k);
	vector <bn> cd(max(n, m) + 10);
	cd[0] = bn();
	cd[0].q.push_back(1);
	for (int i = 1; i < max(n, m) + 10; i++) {
		cd[i] = dbl(cd[i - 1]);
	}

	for (int i = 0; i < k; i++) {
		cin >> q[i].first >> q[i].second;
		for (int j = 0; j < i; j++) {
			g[i].push_back(make_pair(j, cd[max(abs(q[i].first - q[j].first), abs(q[i].second - q[j].second))]));
			g[j].push_back(make_pair(i, cd[max(abs(q[i].first - q[j].first), abs(q[i].second - q[j].second))]));
		}
	}

	set <pair <bn, int>> dij;
	vector <bn> d(k, cd[max(n, m) + 9]);
	vector <char> used(k, 0);
	d[0] = bn();
	used[0] = 1;
	dij.insert(make_pair(d[0], 0));

	while (!dij.empty()) {
		auto cur = *dij.begin();
		dij.erase(dij.begin());
		used[cur.second] = 2;

		for (auto to : g[cur.second])
			if (used[to.first] < 2) {
				if (!used[to.first]) {
					used[to.first] = 1;
					d[to.first] = to.second + d[cur.second];
					dij.insert(make_pair(d[to.first], to.first));
				}
				else if (to.second + d[cur.second] < d[to.first]) {
					dij.erase(make_pair(d[to.first], to.first));
					d[to.first] = to.second + d[cur.second];
					dij.insert(make_pair(d[to.first], to.first));
				}
			}
	}

	int cur = k - 1;
	vector <int> ans;
	ans.push_back(k);
	while (cur) {
		for (auto to : g[cur]) {
			if (d[cur] == d[to.first] + to.second) {
				cur = to.first;
				break;
			}
		}
		ans.push_back(cur + 1);
	}

	reverse(ans.begin(), ans.end());
	cout << ans.size() << '\n';
	for (auto w : ans) cout << w << ' ';

	return 0;
}